@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-07'; # DATE
-our $VERSION = '0.91'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.92'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1080,6 +1080,7 @@ sub run {
         die [500, "Unknown action $r->{action}"] unless $self->can($meth);
         $log->tracef("[pericmd] Running %s() ...", $meth);
         $r->{res} = $self->$meth($r);
+        #$log->tracef("[pericmd] res=%s", $r->{res}); #1
     };
     my $err = $@;
     if ($err || !$r->{res}) {
@@ -1090,10 +1091,22 @@ sub run {
         } else {
             $r->{res} = [500, "Bug: no response produced"];
         }
+    } elsif (ref($r->{res}) ne 'ARRAY') {
+        $log->tracef("[pericmd] res=%s", $r->{res}); #2
+        $r->{res} = [500, "Bug in program: result not an array"];
+    } elsif (!$r->{res}[0] || $r->{res}[0] < 200 || $r->{res}[0] > 555) {
+        $log->tracef("[pericmd] res=%s", $r->{res}); #3
+        $r->{res} = [500, "Bug in program: invalid result status, ".
+                         "must be 200 <= x <= 555"];
     }
     $r->{format} //= $r->{res}[3]{'cmdline.default_format'};
     $r->{format} //= $r->{meta}{'cmdline.default_format'};
+    my $restore_orig_result;
+    my $orig_result;
     if (exists $r->{res}[3]{'cmdline.result'}) {
+        # temporarily change the result for formatting
+        $restore_orig_result = 1;
+        $orig_result = $r->{res}[2];
         $r->{res}[2] = $r->{res}[3]{'cmdline.result'};
     }
   FORMAT:
@@ -1111,6 +1124,10 @@ sub run {
     $log->tracef("[pericmd] Running hook_after_run ...");
     $self->hook_after_run($r);
 
+    if ($restore_orig_result) {
+        $r->{res}[2] = $orig_result;
+    }
+
     my $exitcode;
     if ($r->{res}[3] && defined($r->{res}[3]{'cmdline.exit_code'})) {
         $exitcode = $r->{res}[3]{'cmdline.exit_code'};
@@ -1143,7 +1160,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.91 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
+This document describes version 0.92 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-10.
 
 =head1 DESCRIPTION
 
@@ -1923,7 +1940,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
