@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-03-07'; # DATE
-our $VERSION = '0.91'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.92'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -206,7 +206,8 @@ sub __gen_table {
         my $tcos;
         if ($ENV{FORMAT_PRETTY_TABLE_COLUMN_ORDERS}) {
             $tcos = __json->decode($ENV{FORMAT_PRETTY_TABLE_COLUMN_ORDERS});
-        } elsif (my $rfos = $resmeta->{result_format_options}) {
+        } elsif (my $rfos = ($resmeta->{'cmdline.format_options'} //
+                                 $resmeta->{format_options})) {
             my $rfo = $rfos->{'text-pretty'} // $rfos->{text} // $rfos->{any};
             if ($rfo) {
                 $tcos = $rfo->{table_column_orders};
@@ -502,7 +503,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.91 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
+This document describes version 0.92 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
@@ -579,7 +580,7 @@ Explicitly turn the progress bar on/off.
 
 =head2 FORMAT_PRETTY_TABLE_COLUMN_ORDERS => array (json)
 
-Set the default of C<table_column_orders> in C<result_format_options> in result
+Set the default of C<table_column_orders> in C<format_options> in result
 metadata, similar to what's implemented in L<Perinci::Result::Format> and
 L<Data::Format::Pretty::Console>.
 
@@ -604,7 +605,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
